..
   SPDX-FileCopyrightText: Copyright DB Netz AG and the capellambse contributors
   SPDX-License-Identifier: Apache-2.0

The |project| REPL
==================

.. automodule:: capellambse.repl

.. sphinx_argparse_cli::
   :module: capellambse.repl
   :func: main
   :hook:
   :prog: capellambse/repl.py
   :title: Capellambse Repl
   :group_title_prefix:
